@@ -10,6 +10,7 @@ from typing import Any, NoReturn, Union
 import boto3
 from botocore.config import Config
 from botocore.exceptions import ClientError
+from s3transfer.manager import TransferConfig, TransferManager
 
 from envidat.s3 import exceptions
 from envidat.utils import get_url
@@ -397,6 +398,56 @@ class Bucket:
 
         return False
 
+    def transfer(self, source_key: str, dest_bucket: str, dest_key: str = None) -> bool:
+        """Fast efficient transfer bucket --> bucket using TransferManager.
+        This function avoids downloading to memory and uses the underlying
+        operations that aws-cli uses to transfer.
+
+        Args:
+            source_key (str): The key / path to copy from.
+            dest_bucket (str): Name of the destination bucket.
+            dest_key (str): The key / path to copy to.
+                Optional, defaults to None.
+
+        Returns:
+            bool: True if success, False is failure.
+        """
+
+        client = Bucket.get_boto3_client()
+
+        if dest_key is None:
+            dest_key = source_key
+
+        try:
+            dest_bucket_obj = Bucket(dest_bucket)
+            if dest_bucket_obj.check_file_exists(dest_key):
+                log.info(
+                    f"Key {dest_key} already exists in bucket {dest_bucket}. "
+                    "Skipping copy..."
+                )
+                return True
+
+            log.info(
+                f"Transferring key {source_key} from bucket {self.bucket_name} "
+                f"to bucket {dest_bucket} with key {dest_key}"
+            )
+
+            manager = TransferManager(
+                client, TransferConfig(max_request_concurrency=20)
+            )
+            manager.copy(
+                bucket=dest_bucket,
+                key=dest_key,
+                copy_source={"Bucket": self.bucket_name, "Key": source_key},
+            ).result()
+
+            return True
+
+        except ClientError as e:
+            self._handle_boto3_client_error(e, key=source_key)
+
+        return False
+
     def list_all(self) -> list:
         """Get a list of all objects in the bucket.
 
@@ -584,6 +635,37 @@ class Bucket:
 
         return status_dict
 
+    def check_file_exists(self, key: str) -> bool:
+        """Check an object exists in the bucket.
+
+        Args:
+            key (str): The key, i.e. path within the bucket to check for.
+
+        Returns:
+            bool: True if exists, False if not.
+        """
+
+        client = Bucket.get_boto3_client()
+
+        try:
+            log.info(f"Retrieving S3 object metadata with key: {key}")
+            response = client.head_object(Bucket=self.bucket_name, Key=key)
+
+            if response["ResponseMetadata"]["HTTPStatusCode"] == 200:
+                return True
+            return False
+
+        except ClientError as e:
+            try:
+                code = int(e.response["Error"]["Code"])
+            except KeyError:
+                log.error("Unable to access error code in S3 response.")
+                self._handle_boto3_client_error(e, key=key)
+            if code == 404:
+                return False
+
+            self._handle_boto3_client_error(e, key=key)
+
     def clean_multiparts(self) -> bool:
         """
         Clean up failed multipart uploads in a bucket.
