@@ -13,6 +13,28 @@ def test_bucket_put(bucket):
     assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
 
 
+@mock_s3
+def test_file_exists(bucket):
+    bucket.create()
+
+    file_text = "test"
+    response = bucket.put("text.txt", file_text)
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+
+    success = bucket.check_file_exists("text.txt")
+    assert success is True
+
+    file_text = "test"
+    response = bucket.put("subdir/text.txt", file_text)
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+
+    success = bucket.check_file_exists("subdir/text.txt")
+    assert success is True
+
+    success = bucket.check_file_exists("doesnotexist/text.txt")
+    assert success is False
+
+
 @mock_s3
 def test_bucket_get(bucket):
     bucket.create()
@@ -76,6 +98,42 @@ def test_bucket_download(bucket, create_tempfile):
             assert f.read() == "test"
 
 
+@mock_s3
+def test_bucket_transfer(bucket, bucket2, create_tempfile):
+    bucket.create()
+    bucket2.create()
+
+    with create_tempfile("txt") as upload:
+        filename = upload.name
+
+        success = bucket.upload_file(upload.name, upload.name)
+        assert success is True
+
+    success = bucket.transfer(filename, "testing2", f"/newkey/{filename}")
+    assert success is True
+
+    exists = bucket2.check_file_exists(f"/newkey/{filename}")
+    assert exists is True
+
+
+@mock_s3
+def test_bucket_transfer_exists(bucket, bucket2, create_tempfile):
+    bucket.create()
+    bucket2.create()
+
+    with create_tempfile("txt") as upload:
+        filename = upload.name
+
+        success = bucket.upload_file(upload.name, upload.name)
+        assert success is True
+
+        success = bucket2.upload_file(upload.name, upload.name)
+        assert success is True
+
+    success = bucket.transfer(filename, "testing2", filename)
+    assert success is True
+
+
 @mock_s3
 def test_list_all(bucket):
     bucket.create()
